pub fn request_device_code(control_plane: &str) -> Result<DeviceCode>Expand description
Ask the control plane for a device code and the browser approval URL.
pub fn request_device_code(control_plane: &str) -> Result<DeviceCode>Ask the control plane for a device code and the browser approval URL.