ConnectRequest

Struct ConnectRequest 

pub struct ConnectRequest<'a> {
    pub control_plane: &'a str,
    pub app_id: &'a str,
    pub publish_name: &'a str,
    pub publish_label: &'a str,
    pub local_port: u16,
    pub poll_timeout: Duration,
}
What one app needs to go from a cold machine to a live public address.

Fields

control_plane: &'a str

Control-plane public URL (where the browser approves).

app_id: &'a str

This app’s stable id (also the first-party id used for auto-approve).

publish_name: &'a str

The app label to publish (e.g. "music").

publish_label: &'a str

Human label shown for the published app.

local_port: u16

The app’s local port to route to.

poll_timeout: Duration

How long to wait for the person to finish approving in the browser.