spawn_or_attach

Function spawn_or_attach 

pub fn spawn_or_attach(
    cfg: &EngineConfig,
    app_id: &str,
    pid: u32,
) -> Result<StartOutcome>
Discover a running engine and either attach to it (registering app_id) or spawn a new one from cfg. This is the one call an embedding app makes to guarantee exactly one engine is serving on this machine.